import React, { useRef, useEffect, useState } from 'react';
import { Button, Select } from 'antd';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import PageTable from '@/components/PageTable';
import { getMachineryList } from '@/services/machinery';
import { getMachineryTypeList } from '@/services/machineryType';
import { getCooperativeList } from '@/services/cooperative';
import WorkListModel from './components/WorkListModel';

const { Option } = Select;

export default (props) => {
  const actionRef = useRef();
  const [machineryTypeList, setMachineryTypeList] = useState([]);
  const [cooperativeList, setCooperativeList] = useState([]);
  const [editModal, setEditModal] = useState(false);
  const [machineryId, setMachineryId] = useState();


  const showList = (val) => {
    setMachineryId(val.machineryId)
    setEditModal(true)
  }
  const onCancel = () => {
    setEditModal(false)
  }
  useEffect(() => {
    getCooperativeList({ pageSize: 999 }).then((res) => {
      setCooperativeList(res.records);
    }).catch((err) => {
      console.log(err.message)
    });
    getMachineryTypeList({ pageSize: 999 }).then((res) => {
      setMachineryTypeList(res.records);
    }).catch((err) => {
      console.log(err.message)
    });
  }, []);
  const columns = [
    {
      title: '合作社',
      dataIndex: 'orgId',
      key: 'orgId',
      hideInTable: true,
      renderFormItem: (item, field, form) => {
        return (
          <Select>
            {cooperativeList.map((item) => (
              <Option value={item.orgId} key={item.orgId}>
                {item.name}
              </Option>
            ))}
          </Select>
        )
      }
    },
    {
      title: '名称',
      dataIndex: 'name',
      key: 'name',
    },
    {
      title: '合作社',
      dataIndex: 'orgName',
      key: 'orgName',
      search: false
    },
    {
      title: '农机类型',
      dataIndex: 'typeId',
      key: 'typeId',
      renderFormItem: (item, field, form) => {
        return (
          <Select>
            {machineryTypeList.map((item) => (
              <Option value={item.typeId} key={item.typeId}>
                {item.name}
              </Option>
            ))}
          </Select>
        );
      },
      hideInTable: true,
    },
    {
      title: '农机类型',
      dataIndex: 'typeName',
      key: 'typeName',
      search: false,
    },
    {
      title: '区域',
      dataIndex: 'regionName',
      key: 'regionName',
      search: false,
    },
    {
      title: '农机单价',
      dataIndex: 'price',
      key: 'price',
      render: (t) => t / 100,
      search: false,
    },
    {
      title: '主图',
      dataIndex: 'thumb',
      key: 'thumb',
      width: 150,
      render: (t) => <img width={110} src={t} alt="" />,
      search: false,
    },
    {
      title: '工作状态',
      dataIndex: 'jobStatus',
      key: 'jobStatus',
      search: false,
      render: (_, record) => {
        return record.jobStatus == 1 ? '使用中' : '空闲中';
      },
    },
    {
      title: '状态',
      dataIndex: 'status',
      key: 'status',
      search: false,
      render: (_, record) => {
        return record.status === 1 ? '正常' : '维修中';
      },
    },
    {
      title: '操作',
      valueType: 'option',
      render: (_, record) => [
        <Button style={{ padding: 0 }} type="link" key={1} onClick={() => showList(record)}>
          农机GIS
        </Button>,
      ],
    },
  ];

  return (
    <PageHeaderWrapper>
      <PageTable
        request={getMachineryList}
        actionRef={actionRef}
        columns={columns}
        rowKey="machineryId"
        options={false}
        scroll={{ x: 1000 }}
      />
      <WorkListModel editModal={editModal} onCancel={onCancel} machineryId={machineryId} />
    </PageHeaderWrapper>
  );
};
