import React, { useState, useEffect } from 'react';
import { history } from 'umi';
import { Form, Drawer, Select, InputNumber, message, Button } from 'antd';
import { getDeviceDetail, addDevice } from '@/services/device';
import DeviceList from './DeviceList';
import { useMemo } from 'react';

const { Option } = Select;
const FormItem = Form.Item;
const formItemLayout = { labelCol: { span: 6 }, wrapperCol: { span: 14 } };

const goBack = () => {
  history.goBack();
};

export default (props) => {
  const { machineryId } = props;

  const [form] = Form.useForm();
  const [loading, setLoading] = useState(false);
  const [visible, setVisible] = useState(false);
  const [deviceDetail, setDeviceDetail] = useState();
  const [hatcId, setHatcId] = useState();

  const onSubmit = (data) => {
    if (!deviceDetail || !deviceDetail.deviceNo) {
      message.error('请先绑定设备');
      return;
    }

    const apiConfig = JSON.stringify({
      ...data,
      deviceId: hatcId,
    });

    // 表单的提交, 实际上是把 form 内容 + 其余字段 融合一起提交
    setLoading(true);
    addDevice({ ...deviceDetail, machineryId, apiConfig })
      .then((res) => {
        message.success('保存成功！');
        setLoading(false);
        goBack();
      })
      .catch((err) => {
        setLoading(false);
        console.log(err.message);
      });
  };

  const handleCheck = (terminalId, hatcDevice) => {
    setHatcId(hatcDevice.deviceId);
    setDeviceDetail({
      ...(deviceDetail || {}),
      deviceNo: terminalId,
      deviceType: hatcDevice.productKey,
    });
    setVisible(false);
  };

  useEffect(() => {
    if (machineryId) {
      //获取设备信息内容
      getDeviceDetail(machineryId).then((res) => {
        if (!res) return;

        setDeviceDetail(res);
        const apiConfig = JSON.parse(res.apiConfig) || {};

        // 表单内容只是整个数据的一个 JSON 字段
        form.setFieldsValue({
          netType: apiConfig.netType,
          channel: apiConfig.channel,
        });
      });
    }
  }, [machineryId, form]);

  const deviceName = useMemo(() => {
    if (!deviceDetail) return '未绑定';

    return `${deviceDetail.deviceType}-${deviceDetail.deviceNo}`;
  }, [deviceDetail]);

  return (
    <>
      <Form {...formItemLayout} onFinish={onSubmit} form={form}>
        <FormItem label="设备">
          <Button type="link" onClick={() => setVisible(true)}>
            {deviceName}
          </Button>
        </FormItem>
        <FormItem
          label="通道号"
          name="channel"
          rules={[{ required: true, message: '请输入通道号' }]}
        >
          <InputNumber min={1} placeholder="请输入通道号" style={{ width: '350px' }} />
        </FormItem>
        <FormItem
          label="网络类型"
          name="netType"
          rules={[{ required: true, message: '请选择网络类型' }]}
        >
          <Select placeholder="请选择网络类型" style={{ width: '350px' }}>
            <Option value={0}>内网</Option>
            <Option value={1}>电信</Option>
            <Option value={2}>移动</Option>
            <Option value={3}>联通</Option>
          </Select>
        </FormItem>
        <FormItem label=" " colon={false}>
          <Button type="default" onClick={goBack}>
            返回
          </Button>
          <Button type="primary" loading={loading} htmlType="submit" style={{ marginLeft: '4em' }}>
            保存
          </Button>
        </FormItem>
      </Form>
      <Drawer
        title="设备列表"
        width={500}
        closable={false}
        onClose={() => setVisible(false)}
        visible={visible}
        destroyOnClose
      >
        <DeviceList value={deviceDetail && deviceDetail.deviceNo} onChange={handleCheck} />
      </Drawer>
    </>
  );
};
