import React, { useRef, useEffect, useState } from 'react';
import { history } from 'umi';
import { Button, Popconfirm, message, Select, Modal } from 'antd';
import { PlusOutlined } from '@ant-design/icons';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import PageTable from '@/components/PageTable';
import { getMachineryList, deleteMachinery, updateMachinery, updateRepair } from '@/services/machinery';
import { getMachineryTypeList } from '@/services/machineryType';
import { getCooperativeList } from '@/services/cooperative';

const { Option } = Select;

export default (props) => {
  const actionRef = useRef();
  const [machineryTypeList, setMachineryTypeList] = useState([]);
  const [cooperativeList, setCooperativeList] = useState([]);

  const gotoEdit = (id) => {
    const queryStr = id ? `?id=${id}` : '';
    history.push(`./machinery/Edit${queryStr}`);
  };
  const handleDelete = (id) => {
    deleteMachinery(id).then(() => {
      message.success('删除成功');
      actionRef.current.reload();
    }).catch((err) => {
      console.log(err.message)
    });
  };
  //列表切换农机状态方法
  const handleOK = (record, data) => {
    const title = record.status
      ? '您确定要将该农机状态变更为维修中吗? 变更后后该农机将不能调度'
      : '您确定要将该农机状态变更为正常吗? 变更后该农机可以调度';
    Modal.confirm({
      title: title,
      okText: '确认',
      cancelText: '取消',
      onOk() {
        updateRepair(record.machineryId, record.status === 1 ? 0 : 1)
          .then((res) => {
            message.success('操作成功');
            actionRef.current.reload();
          })
          .catch((err) => {
            console.log(err.message)
          });
      },
    });
  };
  useEffect(() => {
    getCooperativeList({ pageSize: 999 }).then((res) => {
      setCooperativeList(res.records);
    }).catch((err) => {
      console.log(err.message)
    });
    getMachineryTypeList({ pageSize: 999 }).then((res) => {
      setMachineryTypeList(res.records);
    }).catch((err) => {
      console.log(err.message)
    });
  }, []);
  const actions = () => [
    <Button key="add" type="primary" icon={<PlusOutlined />} onClick={() => gotoEdit()}>
      新增农机
    </Button>,
  ];
  const columns = [
    {
      title: '合作社',
      dataIndex: 'orgId',
      key: 'orgId',
      hideInTable: true,
      renderFormItem: (item, field, form) => {
        return (
          <Select>
            {cooperativeList.map((item) => (
              <Option value={item.orgId} key={item.orgId}>
                {item.name}
              </Option>
            ))}
          </Select>
        )
      }
    },
    {
      title: '名称',
      dataIndex: 'name',
      key: 'name',
    },
    {
      title: '合作社',
      dataIndex: 'orgName',
      key: 'orgName',
      search: false
    },
    {
      title: '农机类型',
      dataIndex: 'typeId',
      key: 'typeId',
      renderFormItem: (item, field, form) => {
        return (
          <Select>
            {machineryTypeList.map((item) => (
              <Option value={item.typeId} key={item.typeId}>
                {item.name}
              </Option>
            ))}
          </Select>
        );
      },
      hideInTable: true,
    },
    {
      title: '农机类型',
      dataIndex: 'typeName',
      key: 'typeName',
      search: false,
    },
    {
      title: '区域',
      dataIndex: 'regionName',
      key: 'regionName',
      search: false,
    },
    {
      title: '农机单价',
      dataIndex: 'price',
      key: 'price',
      render: (t) => t / 100,
      search: false,
    },
    {
      title: '主图',
      dataIndex: 'thumb',
      key: 'thumb',
      width: 150,
      render: (t) => <img width={110} src={t} alt="" />,
      search: false,
    },
    {
      title: '工作状态',
      dataIndex: 'jobStatus',
      key: 'jobStatus',
      search: false,
      render: (_, record) => {
        return record.jobStatus == 1 ? '使用中' : '空闲中';
      },
    },
    {
      title: '状态',
      dataIndex: 'status',
      key: 'status',
      search: false,
      render: (_, record) => {
        return record.status === 1 ? '正常' : '维修中';
      },
    },
    {
      title: '操作',
      valueType: 'option',
      render: (_, record) => [
        <Button style={{ padding: 0 }} type="link" key={1} onClick={() => handleOK(record)}>
          {record.status === 0 ? '完成维修' : '维修'}
        </Button>,
        <Button
          style={{ padding: 0 }}
          type="link"
          key={2}
          onClick={() => gotoEdit(record.machineryId)}
        >
          编辑
        </Button>,
        <Popconfirm
          key={3}
          title="您是否确认删除 ?"
          onConfirm={() => handleDelete(record.machineryId)}
          okText="确定"
          cancelText="取消"
        >
          <Button style={{ padding: 0 }} type="link">
            删除
          </Button>
        </Popconfirm>,
      ],
    },
  ];

  return (
    <PageHeaderWrapper>
      <PageTable
        request={getMachineryList}
        // expfunc={exportPersonList}
        toolBarRender={actions}
        actionRef={actionRef}
        columns={columns}
        rowKey="machineryId"
        options={false}
        scroll={{ x: 1000 }}
      />
    </PageHeaderWrapper>
  );
};
