import React from 'react';
import { Card, Tabs } from 'antd';
import MaJob from './MaJob';
import { getMachineryListByUser } from '@/services/device';

export default (props) => {
  const { userId, current, setCurrent } = props;

  const [loading, setLoading] = React.useState(false);
  const [machines, setMachines] = React.useState([]);
  const [activeTab, setActiveTab] = React.useState();

  const tabList = React.useMemo(() => {
    return machines.map((x) => ({ key: x.machineryId, tab: x.name }));
  }, [machines]);

  const onTabChange = (key) => {
    setCurrent(machines.filter((x) => x.machineryId === key)[0]);
  };

  React.useEffect(() => {
    if (current) {
      setActiveTab(current.machineryId);
    }
  }, [current]);

  React.useEffect(() => {
    if (userId) {
      setLoading(true);
      getMachineryListByUser(userId)
        .then((res) => {
          const list = res || [];
          setMachines(list);
          setCurrent(list[0] || {});
          setLoading(false);
        })
        .catch((err) => {
          console.error(err);
          setLoading(false);
        });
    }
  }, [userId]);

  return (
    <Card loading={loading} tabList={tabList} activeTabKey={activeTab} onTabChange={onTabChange}>
      <MaJob machine={current} userId={userId} />
    </Card>
  );
};
