import React from 'react';
import { Link } from 'umi';
import moment from 'moment';
import { Button, Popconfirm, Dropdown, Menu } from 'antd';
import PageTable from '@/components/PageTable';
import { getDeviceList } from '@/services/device';
import {} from '@/services/device';

const formatterTime = (val) => {
  return val && val !== '-' ? moment(val).format('YYYY-MM-DD') : '-';
};

const menus = (
  <Menu>
    <Menu.Item key="shensong">深松</Menu.Item>
    <Menu.Item key="feifang">飞防</Menu.Item>
  </Menu>
);

const List = (props, ref) => {
  const { onBindOpt, onSyncDevice } = props;

  const columns = [
    {
      title: '设备类型',
      dataIndex: 'deviceType',
      key: 'deviceType',
      valueEnum: {
        shensong: {
          text: '深松',
        },
        feifang: {
          text: '飞防',
        },
      },
    },
    {
      title: '设备编号',
      dataIndex: 'deviceNo',
      key: 'deviceNo',
      search: false,
    },
    {
      title: '绑定农机',
      dataIndex: 'machineryName',
      key: 'machineryName',
      search: false,
    },
    {
      title: '注册时间',
      dataIndex: 'createDate',
      key: 'createDate',
      render: formatterTime,
      search: false,
      width: 240,
    },
    {
      title: '在线状态',
      dataIndex: 'onlineStatus',
      key: 'onlineStatus',
      valueEnum: {
        1: {
          text: '在线',
        },
        0: {
          text: '离线',
        },
      },
    },
    {
      title: '操作',
      valueType: 'option',
      width: 160,
      render: (_, record) => [
        <Link
          to={`/Machinery/OperationStatistics?deviceType=${record.deviceType}&deviceNo=${record.deviceNo}`}
          key={1}
        >
          查看作业
        </Link>,
        record.machineryId === null ? (
          <Button key={2} type="link" onClick={() => onBindOpt(record)}>
            绑定
          </Button>
        ) : (
          <Popconfirm key={3} title={`是否进行'解绑'操作?`} onConfirm={() => onBindOpt(record)}>
            <Button type="link">解绑</Button>
          </Popconfirm>
        ),
      ],
    },
  ];

  const actionRef = React.useRef();

  React.useImperativeHandle(ref, () => {
    return {
      reload: () => actionRef.current.reload(),
    };
  });

  return (
    <PageTable
      request={getDeviceList}
      actionRef={actionRef}
      columns={columns}
      rowKey={(row) => `${row.deviceType}-${row.deviceNo}`}
      options={false}
      toolBarRender={() => [
        <Button key={1} type="primary">
          同步深松
        </Button>,
        <Button key={3} type="primary">
          同步飞防
        </Button>,
      ]}
      scroll={{ x: 1000 }}
    />
  );
};

export default React.forwardRef(List);
