import React, { useState, useEffect, useRef } from 'react';
import { Button, Modal, Select, Form, message } from 'antd';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { addDevice, deleteDevice } from '@/services/device';
import List from './components/List';
import MaBind from './components/MaBind';

export default (props) => {
  // 绑定表单

  const [open, setOpen] = useState(false);
  const [device, setDevice] = useState();
  const listRef = useRef();

  // 绑定农机
  const onBind = ({ machineryId }) => {
    const data = { ...device, machineryId };
    addDevice(data).then((res) => {
      setOpen(false);
      message.success(`绑定成功`);
      listRef.current.reload();
    });
  };

  // 解绑
  const unBind = (deviceId) => {
    deleteDevice(deviceId)
      .then(() => {
        // setLoading(false);
        message.success(`解绑成功`);
        listRef.current.reload();
      })
      .catch((err) => {
        // setLoading(false);
        message.error(err.message || err);
      });
  };

  // 设备农机绑定或者解绑操作
  const onBindOpt = (row) => {
    setDevice({ ...row });

    if (!row.machineryId) {
      // 农机ID 不存在, 说明是绑定业务
      setOpen(true);
    } else {
      unBind(row.deviceId);
    }
  };

  return (
    <PageHeaderWrapper>
      <List ref={listRef} onBindOpt={onBindOpt} onSyncDevice={console.log} />
      <MaBind open={open} device={device} onCancel={() => setOpen(false)} onFinish={onBind} />
    </PageHeaderWrapper>
  );
};
